You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@hive.apache.org by vg...@apache.org on 2017/08/22 18:34:10 UTC

hive git commit: HIVE-17352: HiveSever2 error with Illegal Operation state transition from CLOSED to FINISHED (Deepak Jaiswal reviewed by Vaibhav Gumashta)

Repository: hive
Updated Branches:
  refs/heads/master ff30a1ebf -> f0b0cc268


HIVE-17352: HiveSever2 error with Illegal Operation state transition from CLOSED to FINISHED (Deepak Jaiswal reviewed by Vaibhav Gumashta)


Project: http://git-wip-us.apache.org/repos/asf/hive/repo
Commit: http://git-wip-us.apache.org/repos/asf/hive/commit/f0b0cc26
Tree: http://git-wip-us.apache.org/repos/asf/hive/tree/f0b0cc26
Diff: http://git-wip-us.apache.org/repos/asf/hive/diff/f0b0cc26

Branch: refs/heads/master
Commit: f0b0cc268e5fcb59391bbf4f4773f6f92aed6dab
Parents: ff30a1e
Author: Vaibhav Gumashta <vg...@hortonworks.com>
Authored: Tue Aug 22 11:34:04 2017 -0700
Committer: Vaibhav Gumashta <vg...@hortonworks.com>
Committed: Tue Aug 22 11:34:04 2017 -0700

----------------------------------------------------------------------
 .../org/apache/hive/service/cli/operation/SQLOperation.java     | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/hive/blob/f0b0cc26/service/src/java/org/apache/hive/service/cli/operation/SQLOperation.java
----------------------------------------------------------------------
diff --git a/service/src/java/org/apache/hive/service/cli/operation/SQLOperation.java b/service/src/java/org/apache/hive/service/cli/operation/SQLOperation.java
index 1a2be8b..773dd51 100644
--- a/service/src/java/org/apache/hive/service/cli/operation/SQLOperation.java
+++ b/service/src/java/org/apache/hive/service/cli/operation/SQLOperation.java
@@ -257,11 +257,12 @@ public class SQLOperation extends ExecuteStatementOperation {
       /**
        * If the operation was cancelled by another thread, or the execution timed out, Driver#run
        * may return a non-zero response code. We will simply return if the operation state is
        * CANCELED, TIMEDOUT or CLOSED, otherwise throw an exception
        */
       if ((getStatus().getState() == OperationState.CANCELED)
           || (getStatus().getState() == OperationState.TIMEDOUT)
-          || (getStatus().getState() == OperationState.CLOSED)) {
+          || (getStatus().getState() == OperationState.CLOSED)
+          || (getStatus().getState() == OperationState.FINISHED)) {
         LOG.warn("Ignore exception in terminal state", e);
         return;
       }
@@ -257,11 +257,12 @@ public class SQLOperation extends ExecuteStatementOperation {
        * If the operation was cancelled by another thread, or the execution timed out, Driver#run
        * may return a non-zero response code. We will simply return if the operation state is
-       * CANCELED, TIMEDOUT or CLOSED, otherwise throw an exception
+       * CANCELED, TIMEDOUT, CLOSED or FINISHED, otherwise throw an exception
        */
       if ((getStatus().getState() == OperationState.CANCELED)